@@ -1,20 +1,18 @@
 #---------------------------------------------#
 #
-#
 # Mailer will queue up emails, Try to send them
 # and keep track of if they are sent or not.
 # Should be executed with a cron job.
 #
-#
-#
-#
-#
 #---------------------------------------------#
 from django.db import models
 from django.core.mail import EmailMultiAlternatives
-from mailqueue.tasks import *
 from django.db.models.signals import post_save
 from django.dispatch import receiver
+from django.conf import settings
+
+from mailqueue import defaults
+from mailqueue.tasks import send_mail
 
 class MailerMessage(models.Model):
     subject = models.CharField(max_length=250, blank=True, null=True)
@@ -40,10 +38,14 @@ class MailerMessage(models.Model):
                 msg.send()
                 self.sent = True
                 self.save()
-            except:
-                pass
+            except Exception, e:
+                print("mail queue exception %s" % e)
 
 
 @receiver(post_save, sender=MailerMessage)
 def send_post_save(sender, instance, signal, *args, **kwargs):
-    send_mail.delay(instance)
\ No newline at end of file
+    MAILQUEUE_CELERY = getattr(settings, 'MAILQUEUE_CELERY', defaults.MAILQUEUE_CELERY)
+    if MAILQUEUE_CELERY:
+        send_mail.delay(instance)
+    else:
+        instance.send()
\ No newline at end of file
